@@ -1,6 +1,6 @@
 package Bundle::WWW::Search::ALL;
 
-$VERSION = '1.05';
+$VERSION = '1.06';
 
 1;
 
@@ -30,16 +30,18 @@ WWW::Search::Excite
 
 J/JS/JSMYSER/WWW-Search-GoTo-1.07.tar.gz
 
-J/JS/JSMYSER/WWW-Search-Google-2.18+.tar.gz
+J/JS/JSMYSER/WWW-Search-Google-2.20.tar.gz
 
 WWW::Search::HotBot
 
-J/JS/JSMYSER/WWW-Search-LookSmart-2.04.tar.gz
+J/JS/JSMYSER/WWW-Search-LookSmart-2.05.tar.gz
 
 M/MT/MTHURN/WWW-Search-Magellan-2.06.tar.gz
 
 J/JS/JSMYSER/WWW-Search-MetaCrawler-2.07.tar.gz
 
+J/JS/JSMYSER/WWW-Search-NorthernLight-2.05.tar.gz
+
 J/JS/JSMYSER/WWW-Search-OpenDirectory-2.02.tar.gz
 
 WWW::Search::PRWire
